from setuptools import setup

setup(name='distributions_formulae',
      version='0.1',
      description='Gaussian and Binomial distributions formulae',
      packages=['distributions_formulae'],
      author="Digant Garude",
      author_email="digant.dg07@gmail.com",
      zip_safe=False)
